
# Type: type_uri


The uri that defines the possible values for the type definition

URI: [meta:type_uri](https://w3id.org/biolink/biolinkml/meta/type_uri)


## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | uri is typically drawn from the set of URI's defined in OWL (https://www.w3.org/TR/2012/REC-owl2-syntax-20121211/#Datatype_Maps) |
|  | | every root type must have a type uri |

